@@ -1,7 +1,7 @@
 sample_json_response <- '{
   "seriesID":"LNS14000002",
   "data":[
-{"year":"2011","period":"M12","periodName":"December","value":"8.3","footnotes":[{}]},
+{"year":"2011","period":"M12","periodName":"December","value":"8.3","latest":"true","footnotes":[{}]},
 {"year":"2011","period":"M11","periodName":"November","value":"8.3","footnotes":[{}]},
 {"year":"2011","period":"M10","periodName":"October","value":"8.4","footnotes":[{}]},
 {"year":"2011","period":"M09","periodName":"September","value":"8.7","footnotes":[{}]},
@@ -38,14 +38,14 @@ sample_response2 <- jsonlite::fromJSON(sample_json_response2, simplifyVector = F
 test_that("data_as_table parse_data works", {
   table <- data_as_table(sample_response$data)
   expect_equal(nrow(table), 12)
-  expect_equal(ncol(table), 5)
+  expect_equal(ncol(table), 4)
   expect_equal(table$value[1], 8.3)
   expect_equal(table$year[1], 2011)
   expect_equal(table$period[1], 'M12')
 
   tidy_table <- data_as_tidy_table(sample_response$data)
   expect_equal(nrow(tidy_table), 12)
-  expect_equal(ncol(tidy_table), 4)
+  expect_equal(ncol(tidy_table), 3)
   expect_equal(tidy_table$value[1], 8.5)
   expect_equal(tidy_table$year[1], 2011)
   expect_equal(tidy_table$month[1], 1)
@@ -54,13 +54,13 @@ test_that("data_as_table parse_data works", {
 test_that("data_as_table parse_values false works", {
   table <- data_as_table(sample_response$data, parse_values = FALSE)
   expect_equal(nrow(table), 12)
-  expect_equal(ncol(table), 5)
+  expect_equal(ncol(table), 4)
   expect_equal(table$value[1], '8.3')
   expect_equal(table$year[1], 2011)
 
   tidy_table <- data_as_tidy_table(sample_response$data, parse_values = FALSE)
   expect_equal(nrow(tidy_table), 12)
-  expect_equal(ncol(tidy_table), 4)
+  expect_equal(ncol(tidy_table), 3)
   expect_equal(tidy_table$month[1], 1)
   expect_equal(tidy_table$value[1], '8.5')
 })
@@ -101,9 +101,9 @@ test_that("merge join logic works", {
 
 test_that("as_zoo work", {
   tidy_table <- data_as_tidy_table(sample_response$data, parse_values = FALSE)
-  zoo_table  <- tidy_table_as_zoo(tidy_table)
+  zoo_table <- tidy_table_as_zoo(tidy_table)
   expect_equal(nrow(zoo_table), 12)
-  expect_equal(ncol(zoo_table), 2)
+  expect_equal(ncol(zoo_table), 1)
   expect_equal(zoo::index(zoo_table), zoo::as.yearmon(paste(2011, 1:12), "%Y %m"))
 
 
